Learn R Programming

ironseed (version 0.3.0)

with_ironseed: Temporary ironseeds

Description

with_ironseed() runs code with a specific ironseed and restores global state afterwards. local_ironseed() restores global state when the current evaluation state ends.

Usage

with_ironseed(seeds, code, quiet = FALSE)

local_ironseed(seeds, ..., quiet = FALSE, .local_envir = parent.frame())

with_ironseed_stream(func, code)

local_ironseed_stream(func, .local_envir = parent.frame())

Value

with_ironseed() returns the results of the evaluation of the code argument. local_ironseed() returns the constructed ironseed.

Arguments

seeds

An object or list of objects suitable for constructing an ironseed.

code

Code to execute in the temporary environment.

quiet

a logical indicating whether to silence messages.

...

Additional objects.

.local_envir

The environment to use for scoping.

func

A stream function returned by ironseed_stream()

See Also

ironseed ironseed_stream