with_ironseed() runs code with a specific ironseed and restores global
state afterwards. local_ironseed() restores global state when the current
evaluation state ends.
with_ironseed(seeds, code, quiet = FALSE)local_ironseed(seeds, ..., quiet = FALSE, .local_envir = parent.frame())
with_ironseed_stream(func, code)
local_ironseed_stream(func, .local_envir = parent.frame())
with_ironseed() returns the results of the evaluation of the code
argument. local_ironseed() returns the constructed ironseed.
An object or list of objects suitable for constructing an ironseed.
Code to execute in the temporary environment.
a logical indicating whether to silence messages.
Additional objects.
The environment to use for scoping.
A stream function returned by ironseed_stream()
ironseed ironseed_stream